@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,46 +20,36 @@
 
 /**
  * narcissus_parse.js
- * 
+ *
  * A chrome worker that we keep working for the duration
  * of the session.
- * 
+ *
  * It takes about 10-12M in memory when not actively running, and it
  * is much faster than reloading the Narcissus scripts for every
  * script.
- * 
+ *
  */
 
 importScripts('./jsdefs.js', './jslex.js', './jsparse.js');
 
-self.onmessage = function (event) {
+self.onmessage = function(event) {
+    if (event.data === 'stop') {
+        // destroy chrome worker.
+        self.close();
+        return;
+    }
 
-  if (event.data === 'stop') {
-	  // destroy chrome worker.
-	  self.close();
-	  return;
-  }
-  
-  var obj = JSON.parse(event.data),
-      tree;
+    var obj = JSON.parse(event.data);
+    var tree;
 
-  try {
+    //try {
+    tree = new Narcissus.parser.parse(obj.code);
+    self.postMessage({'tree': tree, 'hash': obj.hash});
+    //} catch (x) {
+    //    // error with parsing. Delete all.
+    //    self.postMessage({'hash': obj.hash});
+    //}
 
-	  
-	  tree = new Narcissus.parser.parse(obj.code);
-
-	  self.postMessage({'tree': tree, 'hash': obj.hash});
-	  
-
-  } catch (x) {
-	  
-	  // error with parsing. Delete all.
-	  self.postMessage({'hash': obj.hash});
-
-  }
-  
-  tree = null;
-  obj = null;
-  
+    tree = null;
+    obj = null;
 };
-
