@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2013, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -44,7 +44,7 @@ exports.urlSeenTester = {
 
 	    }
 	  } catch (x) {
-	    console.log('error', x);
+	    console.debug('error', x);
 	  }
 
   },
@@ -57,7 +57,7 @@ exports.urlSeenTester = {
 
 	  if (this.whitelist[url]) {
 
-	    // console.log('disallowing', url);
+	    // console.debug('disallowing', url);
 	    delete this.whitelist[url];
 
 	  }
@@ -66,11 +66,11 @@ exports.urlSeenTester = {
   
   addUrl: function (url) {
 
-	  //console.log('adding', url);
+	  console.debug('adding', url);
 
 	  if (!this.isWhitelisted(url)) {
 
-	    //console.log('allowing', url);
+	    console.debug('allowing', url);
 	    this.whitelist[url] = true;
 	  }
 
@@ -78,10 +78,10 @@ exports.urlSeenTester = {
 
   isWhitelisted: function (url) {
 	  if (this.whitelist[url] || this.whitelist[this.httpToHttps(url)]) {
-	    //console.log('found to be whitelisted', url);
+	    console.debug('found to be whitelisted', url);
 	    return true;
 	  }
 	  return false;
   }
   
-};
\ No newline at end of file
+};
