@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2013, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ function handlePrefPanelMessage(message) {
   if(prefSplit[0] == "SETPREF") {
     simpleStorage.storage[prefSplit[1]] = prefSplit[2];
   } else {
-    //console.log(message);
+    console.debug(message);
   }
 }
 
@@ -69,4 +69,4 @@ function getAllPrefPanelPrefs() {
   }
   
   prefpanel.postMessage(allprefvalues);
-}
\ No newline at end of file
+}
