@@ -1,7 +1,7 @@
 /**
  * GNU LibreJS - A browser add-on to block nonfree nontrivial JavaScript.
  * *
- * Copyright (C) 2011, 2012 Loic J. Duros
+ * Copyright (C) 2011, 2012, 2014 Loic J. Duros
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,13 +18,12 @@
  *
  */
 var scriptProperties = require("html_script_finder/dom_handler/script_properties");
-
 const scriptTypes = scriptProperties.scriptTypes;
-
 const statusTypes = scriptProperties.statusTypes;
 
+exports.testScriptTypes = function (assert) {
+    assert.equal(scriptTypes.INLINE, 0);
+    assert.equal(scriptTypes.EXTERNAL, 1);
+};
 
-exports.testScriptTypes = function (test) {
-    test.assertEqual(scriptTypes.INLINE, 0);
-    test.assertEqual(scriptTypes.EXTERNAL, 1);
-}
\ No newline at end of file
+require('sdk/test').run(exports);
